@@ -6,7 +6,7 @@ our $AUTHORITY = 'cpan:GENE';
 use strict;
 use warnings;
 
-our $VERSION = '0.0101';
+our $VERSION = '0.0102';
 
 use Encode qw(encode_utf8);
 use Crypt::Passphrase::Argon2 ();
@@ -23,12 +23,10 @@ sub make_encode_sub {
     subtype     => $args->{subtype},
   );
 
-  my $encoder = sub {
+  return sub {
     my ($plain_text) = @_;
     return $passphrase->hash_password($plain_text);
   };
-
-  return $encoder;
 }
 
 sub make_check_sub {
@@ -47,7 +45,7 @@ sub make_check_sub {
     my $col_v = $_[0]->get_column($col);
     return unless defined $col_v;
     return $passphrase->verify_password(encode_utf8($_[1]), $col_v);
-  }
+  };
 }
 
 1;
@@ -62,7 +60,7 @@ DBIx::Class::EncodedColumn::Crypt::Passphrase::Argon2 - Crypt::Passphrase::Argon
 
 =head1 VERSION
 
-version 0.0101
+version 0.0102
 
 =head1 SYNOPSIS
 
@@ -144,7 +142,7 @@ L<DBIx::Class::EncodedColumn>
 
 =head1 AUTHOR
 
-Guillermo Roditi (groditi) <groditi@cpan.org>
+Gene Boggs <gene@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
